#[non_exhaustive]
pub enum Request<'a> { SetMaximized, UnsetMaximized, SetMinimized, UnsetMinimized, Activate { seat: WlSeat, }, Close, SetRectangle { surface: WlSurface, x: i32, y: i32, width: i32, height: i32, }, Destroy, SetFullscreen { output: Option<WlOutput>, }, UnsetFullscreen, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SetMaximized

requests that the toplevel be maximized

Requests that the toplevel be maximized. If the maximized state actually changes, this will be indicated by the state event.



UnsetMaximized

requests that the toplevel be unmaximized

Requests that the toplevel be unmaximized. If the maximized state actually changes, this will be indicated by the state event.



SetMinimized

requests that the toplevel be minimized

Requests that the toplevel be minimized. If the minimized state actually changes, this will be indicated by the state event.



UnsetMinimized

requests that the toplevel be unminimized

Requests that the toplevel be unminimized. If the minimized state actually changes, this will be indicated by the state event.



Activate

activate the toplevel

Request that this toplevel be activated on the given seat. There is no guarantee the toplevel will be actually activated.

Fields

seat: WlSeat


Close

request that the toplevel be closed

Send a request to the toplevel to close itself. The compositor would typically use a shell-specific method to carry out this request, for example by sending the xdg_toplevel.close event. However, this gives no guarantees the toplevel will actually be destroyed. If and when this happens, the zwlr_foreign_toplevel_handle_v1.closed event will be emitted.



SetRectangle

the rectangle which represents the toplevel

The rectangle of the surface specified in this request corresponds to the place where the app using this protocol represents the given toplevel. It can be used by the compositor as a hint for some operations, e.g minimizing. The client is however not required to set this, in which case the compositor is free to decide some default value.

If the client specifies more than one rectangle, only the last one is considered.

The dimensions are given in surface-local coordinates. Setting width=height=0 removes the already-set rectangle.

Fields

surface: WlSurface
width: i32
height: i32


Destroy

destroy the zwlr_foreign_toplevel_handle_v1 object

Destroys the zwlr_foreign_toplevel_handle_v1 object.

This request should be called either when the client does not want to use the toplevel anymore or after the closed event to finalize the destruction of the object.

This is a destructor, once sent this object cannot be used any longer.



SetFullscreen

request that the toplevel be fullscreened

Requests that the toplevel be fullscreened on the given output. If the fullscreen state and/or the outputs the toplevel is visible on actually change, this will be indicated by the state and output_enter/leave events.

The output parameter is only a hint to the compositor. Also, if output is NULL, the compositor should decide which output the toplevel will be fullscreened on, if at all.

Only available since version 2 of the interface

Fields



UnsetFullscreen

request that the toplevel be unfullscreened

Requests that the toplevel be unfullscreened. If the fullscreen state actually changes, this will be indicated by the state event.

Only available since version 2 of the interface

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message