Struct ZwlrForeignToplevelHandleV1
pub struct ZwlrForeignToplevelHandleV1 { /* private fields */ }wayland and Linux only.Expand description
an opened toplevel
A zwlr_foreign_toplevel_handle_v1 object represents an opened toplevel window. Each app may have multiple opened toplevels.
Each toplevel has a list of outputs it is visible on, conveyed to the client with the output_enter and output_leave events.
See also the Event enum for this interface.
Implementations
impl ZwlrForeignToplevelHandleV1
impl ZwlrForeignToplevelHandleV1
pub fn set_maximized(&self)
pub fn set_maximized(&self)
requests that the toplevel be maximized
Requests that the toplevel be maximized. If the maximized state actually changes, this will be indicated by the state event.
pub fn unset_maximized(&self)
pub fn unset_maximized(&self)
requests that the toplevel be unmaximized
Requests that the toplevel be unmaximized. If the maximized state actually changes, this will be indicated by the state event.
pub fn set_minimized(&self)
pub fn set_minimized(&self)
requests that the toplevel be minimized
Requests that the toplevel be minimized. If the minimized state actually changes, this will be indicated by the state event.
pub fn unset_minimized(&self)
pub fn unset_minimized(&self)
requests that the toplevel be unminimized
Requests that the toplevel be unminimized. If the minimized state actually changes, this will be indicated by the state event.
pub fn activate(&self, seat: &WlSeat)
pub fn activate(&self, seat: &WlSeat)
activate the toplevel
Request that this toplevel be activated on the given seat. There is no guarantee the toplevel will be actually activated.
pub fn close(&self)
pub fn close(&self)
request that the toplevel be closed
Send a request to the toplevel to close itself. The compositor would typically use a shell-specific method to carry out this request, for example by sending the xdg_toplevel.close event. However, this gives no guarantees the toplevel will actually be destroyed. If and when this happens, the zwlr_foreign_toplevel_handle_v1.closed event will be emitted.
pub fn set_rectangle(
&self,
surface: &WlSurface,
x: i32,
y: i32,
width: i32,
height: i32,
)
pub fn set_rectangle( &self, surface: &WlSurface, x: i32, y: i32, width: i32, height: i32, )
the rectangle which represents the toplevel
The rectangle of the surface specified in this request corresponds to the place where the app using this protocol represents the given toplevel. It can be used by the compositor as a hint for some operations, e.g minimizing. The client is however not required to set this, in which case the compositor is free to decide some default value.
If the client specifies more than one rectangle, only the last one is considered.
The dimensions are given in surface-local coordinates. Setting width=height=0 removes the already-set rectangle.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the zwlr_foreign_toplevel_handle_v1 object
Destroys the zwlr_foreign_toplevel_handle_v1 object.
This request should be called either when the client does not want to use the toplevel anymore or after the closed event to finalize the destruction of the object.
pub fn set_fullscreen(&self, output: Option<&WlOutput>)
pub fn set_fullscreen(&self, output: Option<&WlOutput>)
request that the toplevel be fullscreened
Requests that the toplevel be fullscreened on the given output. If the fullscreen state and/or the outputs the toplevel is visible on actually change, this will be indicated by the state and output_enter/leave events.
The output parameter is only a hint to the compositor. Also, if output is NULL, the compositor should decide which output the toplevel will be fullscreened on, if at all.
pub fn unset_fullscreen(&self)
pub fn unset_fullscreen(&self)
request that the toplevel be unfullscreened
Requests that the toplevel be unfullscreened. If the fullscreen state actually changes, this will be indicated by the state event.